@@ -4,6 +4,11 @@ from .protocol import JsonRpcMethod
 from .server import JsonRpcServer, rpc_server as default_rpc_server
 
 
+__all__ = (
+    'rpc_method',
+)
+
+
 def rpc_method(prefix: str = '', *,
                rpc_server: JsonRpcServer = default_rpc_server,
                custom_name: typing.Optional[str] = None,
